<?php

/**
 * P4A - PHP For Applications.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * To contact the authors write to:									<br>
 * CreaLabs															<br>
 * Via Medail, 32													<br>
 * 10144 Torino (Italy)												<br>
 * Web:    {@link http://www.crealabs.it}							<br>
 * E-mail: {@link mailto:info@crealabs.it info@crealabs.it}
 *
 * The latest version of p4a can be obtained from:
 * {@link http://p4a.sourceforge.net}
 *
 * @link http://p4a.sourceforge.net
 * @link http://www.crealabs.it
 * @link mailto:info@crealabs.it info@crealabs.it
 * @copyright CreaLabs
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 * @author Fabrizio Balliano <fabrizio.balliano@crealabs.it>
 * @author Andrea Giardina <andrea.giardina@crealabs.it>
 * @package P4A_Base_Application
 */

class clienti extends P4A_Mask
{
	function clienti()
	{
		$this->P4A_Mask();
		$p4a =& P4A::singleton();
		
		// DB Source
		$this->build("p4a_db_source", "source");
		$this->source->setTable("clienti");
		$this->source->setPk("ID");
		$this->source->addOrder("Ragione_sociale");
		$this->source->setPageLimit(10);
		$this->source->load();

		$this->setSource($this->source);
		$this->firstRow();
		$this->setTitle('Anagrafica Clienti');

		// Customizing fields properties
		$fields =& $this->fields;
		$this->setFieldsProperties();

		// Search Fieldset
		$fs_search =& $this->build("p4a_fieldset","fs_search");
		$fs_search->setTitle("Ricerca per ragione sociale");
		$fs_search->setWidth(800);
		$txt_search =& $this->build("p4a_field", "txt_search");
		$txt_search->addAction("onReturnPress");
		$this->intercept($txt_search, "onReturnPress","search");
		$txt_search->setLabel("ragione sociale");
		$cmd_search =& $this->build("p4a_button","cmd_search");
		$cmd_search->setValue("Cerca");
		$this->intercept($cmd_search, "onClick","search");
		$fs_search->anchor($txt_search);
		$fs_search->anchorLeft($cmd_search);

		// Toolbar
		$tool= & $this->build("p4a_standard_toolbar", "tool");
		$tool->setMask($this);

		// Table
		$table =& $this->build("p4a_table", "table");
 		$table->setWidth(810);
		$table->setSource($this->source);
		$table->setVisibleCols(array("Ragione_sociale","Indirizzo","Citta","CAP",
                                 "Provincia","PIVA","CF"));    
		$table->showNavigationBar();
		
		// Message
		$message =& $this->build("p4a_message", "message");
		$message->setWidth("300");


		//Fieldset con l'elenco dei campi
		$fset=& $this->build("p4a_fieldset", "frame");
		$fset->setTitle("Dati clienti");
    $fset->setWidth(800);    
		$fset->anchor($this->fields->Ragione_sociale);
		$fset->anchorleft($this->fields->Indirizzo);
		$fset->anchor($this->fields->Citta);
		$fset->anchorleft($this->fields->CAP);
		$fset->anchor($this->fields->Provincia);
		$fset->anchorleft($this->fields->PIVA);
		$fset->anchor($this->fields->CF);
		$fset->anchor($this->fields->Note);

		// Frame
		$frm=& $this->build("p4a_frame", "frm");
		$frm->setWidth(830);
		$frm->anchor($fs_search);
		$frm->newRow();
		$frm->anchorCenter($message);
		$frm->anchor($table);
  	$frm->anchor($fset);

		// Mandatory Fields
    $this->mf = array("Ragione_sociale");
		foreach($this->mf as $mf){
			$fields->$mf->label->setFontWeight("bold");
		}

		// Display
		$this->display("main", $frm);
		$this->display("menu", $p4a->menu);
		$this->display("top", $this->tool);
	}

	function setFieldsProperties()
	{
		$p4a =& p4a::singleton();
		$fields =& $this->fields;
		// Set field note as a textarea type
    $fields->Note->setType("textarea");
	}

	function saveRow()
	{
		$valid = true;
		// Check for empty mandatory fields
		foreach($this->mf as $mf){
			$value = $this->fields->$mf->getNewValue();
			if(trim($value) === ""){
				$this->fields->$mf->setError();
				$valid = false;
			}
		}

		if ($valid) {
			parent::saveRow();
		}else{
			$this->message->setValue("Indicare tutti i campi necessari");
		}
	}

	function search()
	{
		$value = $this->txt_search->getSQLNewValue();
		$this->data->setWhere("ragione_sociale LIKE '%{$value}%'");
		$this->data->firstRow();
		$num_rows = $this->data->getNumRows();

		if (!$num_rows) {
			$this->message->setValue("Nessuno cliente trovato");
			$this->data->setWhere(null);
			$this->data->firstRow();
		}
	}
  	
}

?>
