<?php

/**
 * P4A - PHP For Applications.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * To contact the authors write to:									<br>
 * CreaLabs															<br>
 * Via Medail, 32													<br>
 * 10144 Torino (Italy)												<br>
 * Web:    {@link http://www.crealabs.it}							<br>
 * E-mail: {@link mailto:info@crealabs.it info@crealabs.it}
 *
 * The latest version of p4a can be obtained from:
 * {@link http://p4a.sourceforge.net}
 *
 * @link http://p4a.sourceforge.net
 * @link http://www.crealabs.it
 * @link mailto:info@crealabs.it info@crealabs.it
 * @copyright CreaLabs
 * @license http://www.gnu.org/licenses/gpl.html GNU General Public License
 * @author Fabrizio Balliano <fabrizio.balliano@crealabs.it>
 * @author Andrea Giardina <andrea.giardina@crealabs.it>
 * @package P4A_Base_Application
 */

class lista extends P4A_Mask
{
	function lista()
	{
		$this->P4A_Mask();
		$p4a =& P4A::singleton();
		
		// DB Source
		$this->build("p4a_db_source", "source");
		$query="SELECT fatture.ID, fatture.Num_fattura, fatture.Data_fattura, 
          fatture.Pagata, clienti.Ragione_sociale AS Cliente, 
          SUM(prestazioni.importo) AS TotaleImponibile, 
          SUM(prestazioni.importo*(1+(prestazioni.Aliquota_IVA/100))) AS Totale 
          FROM fatture 
          RIGHT JOIN prestazioni ON fatture.ID = prestazioni.ID_fattura 
          LEFT JOIN clienti ON fatture.ID_Cliente = clienti.ID 
          GROUP BY fatture.ID 
          ORDER BY fatture.ID DESC";
    $this->source->setQuery($query);
		$this->source->load();
		$this->setSource($this->source);
		$this->firstRow();
		$this->setTitle('Riepilogo Fatture');

		// Search Fieldset
		$fs_search =& $this->build("p4a_fieldset","fs_search");
		$fs_search->setTitle("Filtra per data");
		$fs_search->setWidth(800);
		$txt_search1 =& $this->build("p4a_field", "txt_search1");
    $txt_search1->setType("date");    
    $txt_search1->setFormat("datetime","date_default");
		$txt_search1->setLabel("Data inizio");
		$txt_search2 =& $this->build("p4a_field", "txt_search2");
    $txt_search2->setType("date");    
    $txt_search2->setFormat("datetime","date_default");
    $txt_search2->setLabel("Data fine");
    $txt_search2->addAction("onReturnPress");
		$this->intercept($txt_search2, "onReturnPress","search");
		$cmd_search =& $this->build("p4a_button","cmd_search");
		$cmd_search->setValue("Filtra");
		$this->intercept($cmd_search, "onClick","search");
		$cmd_reset =& $this->build("p4a_button","cmd_reset");
		$cmd_reset->setValue("Reset");
		$this->intercept($cmd_reset, "onClick","reset");
		$fs_search->anchor($txt_search1);
		$fs_search->anchorLeft($txt_search2);
		$fs_search->anchorLeft($cmd_search);
		$fs_search->anchorLeft($cmd_reset);

		// Toolbar
		$this->build("P4A_Quit_Toolbar", "toolbar");

		// Table
		$table =& $this->build("p4a_table", "table");
 		$table->setWidth(800);
		$table->setSource($this->source);
		$table->setVisibleCols(array("Num_fattura","Data_fattura","Pagata",
                            "Cliente","TotaleImponibile","Totale"));    
		$table->cols->Num_fattura->setLabel("N. fattura");
    $table->cols->Data_fattura->setFormat("datetime","date_default");  
    $table->cols->TotaleImponibile->setLabel("Tot. imponibile");

		// Message
		$message =& $this->build("p4a_message", "message");
		$message->setWidth("300");

		// Frame
		$frm=& $this->build("p4a_frame", "frm");
		$frm->setWidth(800);
		$frm->anchor($fs_search);
		$frm->anchorCenter($message);
		$frm->anchor($table);

		// Display
		$this->display("main", $frm);
		$this->display("menu", $p4a->menu);
    $this->display("top", $this->toolbar);
	}


	function search()
	{
		$value1 = $this->txt_search1->getSQLNewValue();
		$value2 = $this->txt_search2->getSQLNewValue();
		$query="SELECT fatture.ID, fatture.Num_fattura, fatture.Data_fattura, 
          fatture.Pagata, clienti.Ragione_sociale AS Cliente, 
          SUM(prestazioni.importo) AS TotaleImponibile, 
          SUM(prestazioni.importo*(1+(prestazioni.Aliquota_IVA/100))) AS Totale 
          FROM fatture 
          RIGHT JOIN prestazioni ON fatture.ID = prestazioni.ID_fattura 
          LEFT JOIN clienti ON fatture.ID_Cliente = clienti.ID 
          GROUP BY fatture.ID 
          HAVING Data_fattura between '$value1' AND '$value2'  
          ORDER BY fatture.ID DESC";
    $this->source->setQuery($query);
		$this->source->load();
    $this->source->firstRow();		
		$num_rows = $this->source->getNumRows();
    
		if (!$num_rows) {
      $this->message->setValue("Nessuna fattura trovata");
		}
	}

	function reset()
  {
 		$query="SELECT fatture.ID, fatture.Num_fattura, fatture.Data_fattura, 
          fatture.Pagata, clienti.Ragione_sociale AS Cliente, 
          SUM(prestazioni.importo) AS TotaleImponibile, 
          SUM(prestazioni.importo*(1+(prestazioni.Aliquota_IVA/100))) AS Totale 
          FROM fatture 
          RIGHT JOIN prestazioni ON fatture.ID = prestazioni.ID_fattura 
          LEFT JOIN clienti ON fatture.ID_Cliente = clienti.ID 
          GROUP BY fatture.ID 
          ORDER BY fatture.ID DESC";
    $this->source->setQuery($query);
  	$this->source->load();
    $this->txt_search1->setValue('');
    $this->txt_search2->setValue('');
    $this->source->firstRow();
  }
}

?>
